==> rheolef_5.93.orig.tar.gz: rheolef-5.93/nfem/ptst/field_expr6_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
// check += /= on field and field_indirect
#include "rheolef.h"
#include "rounder.h"
using namespace rheolef;
using namespace std;
Float g  (const point& x) { return sin(x[0]+x[1]+0.5); }

int main(int argc, char**argv) {
  environment distributed(argc, argv);
  geo omega (argv[1]); 
  string dom_name = (argc > 2) ? argv[2] : "right";
  Float prec = (argc > 3) ? atof(argv[3]) : 1e-10;
  space Vh (omega, "P1");
  space Wh (omega[dom_name], "P1");
  field gh = interpolate(Wh, g);
  field fh (Vh, 0);
warning_macro ("expr...");
  fh[dom_name] += gh;
  gh += fh[dom_name];
  gh /= 2;
warning_macro ("expr done");
  dcout << setprecision(15) << compose (rounder(prec),gh);
}

==> rheolef_6.1.orig.tar.gz: rheolef-6.1/nfem/ptst/field_expr6_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
// check += /= on field and field_indirect
#include "rheolef.h"
#include "rheolef/rounder.h"
using namespace rheolef;
using namespace std;
Float g  (const point& x) { return sin(x[0]+x[1]+0.5); }

int main(int argc, char**argv) {
  environment rheolef(argc, argv);
  geo omega (argv[1]); 
  string dom_name = (argc > 2) ? argv[2] : "right";
  Float prec = (argc > 3) ? atof(argv[3]) : 1e-10;
  space Vh (omega, "P1");
  space Wh (omega[dom_name], "P1");
  field gh = interpolate(Wh, g);
  field fh (Vh, 0);
  fh[dom_name] += gh;
  gh += fh[dom_name];
  gh /= 2;
  dout << setprecision(15) << field(compose (rounder(prec),gh));
}
